package com.ruoyi.ss.transfer.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.SnowFlakeUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.ss.transferDetail.domain.TransferDetailVO;
import com.ruoyi.ss.transferDetail.service.ITransferDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ss.transfer.mapper.TransferMapper;
import com.ruoyi.ss.transfer.domain.Transfer;
import com.ruoyi.ss.transfer.domain.TransferVO;
import com.ruoyi.ss.transfer.domain.TransferQuery;
import com.ruoyi.ss.transfer.service.TransferService;
import org.springframework.transaction.support.TransactionTemplate;

/**
 * 转账Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-09
 */
@Service
public class TransferServiceImpl implements TransferService
{
    @Autowired
    private TransferMapper transferMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private ITransferDetailService transferDetailService;

    /**
     * 查询转账
     *
     * @param batchId 转账主键
     * @return 转账
     */
    @Override
    public TransferVO selectTransferByBatchId(Long batchId)
    {
        return transferMapper.selectTransferByBatchId(batchId);
    }

    /**
     * 查询转账列表
     *
     * @param transfer 转账
     * @return 转账
     */
    @Override
    public List<TransferVO> selectTransferList(TransferQuery transfer)
    {
        return transferMapper.selectTransferList(transfer);
    }

    /**
     * 新增转账
     *
     * @param transfer 转账
     * @return 结果
     */
    @Override
    public int insertTransfer(Transfer transfer)
    {
        transfer.setCreateTime(DateUtils.getNowDate());
        transfer.setBatchNo(String.valueOf(SnowFlakeUtil.newId()));
        return transferMapper.insertTransfer(transfer);
    }

    /**
     * 修改转账
     *
     * @param transfer 转账
     * @return 结果
     */
    @Override
    public int updateTransfer(Transfer transfer)
    {
        return transferMapper.updateTransfer(transfer);
    }

    /**
     * 批量删除转账
     *
     * @param batchIds 需要删除的转账主键
     * @return 结果
     */
    @Override
    public int deleteTransferByBatchIds(Long[] batchIds)
    {
        return transferMapper.deleteTransferByBatchIds(batchIds);
    }

    /**
     * 删除转账信息
     *
     * @param batchId 转账主键
     * @return 结果
     */
    @Override
    public int deleteTransferByBatchId(Long batchId)
    {
        return transferMapper.deleteTransferByBatchId(batchId);
    }

    @Override
    public int insertWithDetail(TransferVO vo) {
        Integer result = transactionTemplate.execute(status -> {
            int insert = this.insertTransfer(vo);
            ServiceUtil.assertion(insert != 1, "新增转账失败");

            if (CollectionUtils.isNotEmptyElement(vo.getDetailList())) {
                for (TransferDetailVO detail : vo.getDetailList()) {
                    detail.setTransferId(vo.getBatchId());
                }
                int batch = transferDetailService.batchInsert(vo.getDetailList());
                ServiceUtil.assertion(batch != vo.getDetailList().size(), "新增转账明细失败");
            }

            return insert;
        });

        return result == null ? 0 : result;
    }

    @Override
    public boolean requestTransfer(String batchNo) {
        TransferVO transfer = this.selectByBatchNo(batchNo);
        return this.requestTransfer(transfer);
    }

    /**
     * 请求转账
     */
    private boolean requestTransfer(TransferVO transfer) {
        if (transfer == null) {
            return false;
        }

        // TODO 请求转账
        transactionTemplate.execute(status -> {

            // TODO 修改状态


            // TODO 发起转账

        });
    }

    @Override
    public TransferVO selectByBatchNo(String batchNo) {
        return transferMapper.selectByBatchNo(batchNo);
    }
}
